# Overview
Edge AI Installer is a set of Linux shell scripts to install Percept related Debian packages on NVIDIA JetPack Ubuntu image and also provision user configurations to make the device available to connect with Azure Percept resources.

# Supported Hardware
The installer has a low hardware dependency. Theoretically it shall work on most of the **ARM 64 devices** with **Ubuntu 20.04**. Feel free to experiment on the device you have. However, we only guarantee the compatibility on the following platform at the moment.

- NVIDIA AGX Xavier/Xavier NX
- NVIDIA AGX Orin/Orin NX

**[Note]** Theoretically the installer works for VM as long as the OS requirement is met. However, it does not support WSL/WSL2 as it is not compatible with IoT Edge.

# Installation

**- Prerequisite**

1) A NVIDIA Xavier/Orin developer kit
    - External monitor, HDMI or DP cable (for Orin), keyboard/mouse, USB drive.
2) Flash the developer kit with NVIDIA's JetPack reference Ubuntu image. Refer to [NVIDIA online L4T document](https://docs.nvidia.com/jetson/archives/l4t-archived/l4t-3261/index.html#page/Tegra%20Linux%20Driver%20Package%20Development%20Guide/quick_start.html#wwpID0E05C0HA) for more guidance.
    - You will need another **physical host machine with Ubuntu OS** for performing this task.
3) Have a IoT Hub and DPS service ready to be used. Refer to step1 or step 2 in the next section.

**- How to install?**

1) Refer to [iot-edge-config](https://github.com/Azure/iot-edge-config) project to setup IoTHub & DPS
    - Use existing IoT Hub & DPS or create a new Hub
    - Go to DPS resource and create individual enrollment
    - Authentication must be Symmetric Key and have IoT Edge Device = TRUE
    - Copy the following for later use.
        - the **Registration_ID**,
        - **Symmetric Primary Key**,
        - the **IoT Hub host name** that’s been assigned.
        - **DPS Scope ID** (found in DPS overview page)

2) If you would like to use connection string instead of DPS, skip step 1 and get [the connection string](https://docs.microsoft.com/en-us/azure/iot-edge/how-to-provision-single-device-linux-symmetric?view=iotedge-2020-11&tabs=azure-portal%2Cubuntu#view-registered-devices-and-retrieve-provisioning-information) from IoT Edge page.

3) Download the installer (ex: **edge-config-tool_2.0.0_arm64.deb**) and copy it to your NV developer kit.
    - **[Best Practice]** Setup your developer kit with external monitor, keyboard and mouse. Download the installer package from your PC and copy it to the developer kit with USB drive.
    - **Make sure the developer kit is connected to the internet before executing the installer!**

4) Before running the installer, make sure it's executable on Ubuntu.

```
### Allow to launch script as program (for GUI usage) ###
$ gsettings set org.gnome.nautilus.preferences executable-text-activation 'launch'

### Assign executable permissions ###
$ sudo chmod +x edge-config-tool_<VERSION>_<ARCH>.deb
```

5) On NV devkit, you can double click the installer file or execute it in the commandline.
```
$ sudo dpkg -i edge-config-tool_<VERSION>_<ARCH>.deb
$ cd /usr/local/microsoft/edge-config-tool
```

After installed completely, you could use one of the following commands to check the package status.
```
$ dpkg-query -s edge-config-tool
$ apt-cache policy edge-config-tool
```

6) You can choose one of the provisioning mechanisms to setup.

**[DPS]**
```
$ sudo ./azure-iot-edge-installer.sh -s <ID Scope> -r <Registration ID> -k <Symmetric Key>
```

**[Connection String]**
```
$ sudo ./azure-iot-edge-installer.sh -c "<The Azure IoT Edge Device Connection String>"
```

**Note:** Although _DeviceId_ allows [some special characters](https://docs.microsoft.com/en-us/azure/iot-hub/iot-hub-devguide-identity-registry#device-identity-properties), the installer does not support the following characters for _DeviceId_ in the connection string!
 - equal sign ( = )
 - percent sign ( % )
 - exclamation mark ( ! )
 - dollar sign ( $ )

Furthermore, if you would like to utilize hostname option (**-hn** or **--hostname**) to assign hostname as _DeviceId_, please also notice the following special characters do not comply with RFC 1035 for hostname naming.
 - \+ _ # * ? ( ) , : @ '

7) Refer to the help menu for more options.
```
$ sudo ./azure-iot-edge-installer.sh -h
```

#After the installation is complete

**[Deployment Setup]**

The expected status of IoT Edge runtime response would be **"417 -- The device's deployment configuration is not set"**. It will change to **"200 -- OK"** after the first module deployment. (You can simply click the "Set Modules" to trigger an empty deployment.)

For **DefenderMicroAgent** and **osconfig** module, it is expected to see the states show **"NA"**. As long as you get the following INFO notification from the installer output.

```
[INFO]: 'osconfig' is running.
[INFO]: 'defender-iot-micro-agent' is running.
```

**[Configuration Check]**

Before you proceed to the check process, please double confirm if system time has been synchronized after network configured.

```
$ sudo timedatectl status
```

Then, you can perform configuration and connectivity checks.

```
$ sudo iotedge check
```
**Note:**
   - DPS provisioning does not contain IoTHub’s hostname, so users need to add additional parameter `--iothub-hostname` for `iotedge check` command.
        - [iotedge check with DPS & x.509 configuration returns "cannot resolve IoT Hub hostname" Errors · Issue #2033 · Azure/iotedge (github.com)](https://github.com/Azure/iotedge/issues/2033)
        - [iotedge check incorrectly shows an error when using DPS · Issue #2313 · Azure/iotedge (github.com)](https://github.com/Azure/iotedge/issues/2313)
   - For information about each of the diagnostic checks this tool runs, including what to do if you get an error or warning, see [IoT Edge troubleshoot checks](https://github.com/Azure/iotedge/blob/main/doc/troubleshoot-checks.md).

# Uninstallation

1.  Uninstall Edge runtime & Percept packages
```
$ sudo apt-get remove --purge aziot-edge aziot-identity-service osconfig edge-config-tool -y
```
2. Enumerate and remove edge modules
```
$ sudo docker ps -a
$ sudo docker rm -f <container id>
$ sudo docker images
$ sudo docker rmi -f <image id>
```
3. Restart your device
```
$ sudo reboot
```

# Reference
- The installer is based on Microsoft [iot-edge-config](https://github.com/Azure/iot-edge-config) project.
